@@ -13,13 +13,14 @@
 #include "metalinksettings.h"
 
 #include "kget_macro.h"
+#include <kpluginmetadata.h>
 
 KGET_EXPORT_PLUGIN_CONFIG(DlgSettingsWidget)
 
-DlgSettingsWidget::DlgSettingsWidget(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
+DlgSettingsWidget::DlgSettingsWidget(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
 {
-    ui.setupUi(this);
+    ui.setupUi(widget());
 
     connect(ui.numSimultaneousFiles, SIGNAL(valueChanged(int)), SLOT(changed()));
     connect(ui.kcfg_MirrorsPerFile, SIGNAL(valueChanged(int)), SLOT(changed()));
